@@ -7,6 +7,7 @@
  *  The modifications and modified version is:
  * 
  *      GiNaC-SAGE Copyright (C) 2008 William Stein
+ *                           (C) 2015-16 Ralf Stephan
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -59,6 +60,12 @@ void ginac_pyinit_Integer(PyObject*);
 void ginac_pyinit_Float(PyObject*);
 void ginac_pyinit_I(PyObject*);
 
+#ifdef PYNAC_HAVE_LIBGIAC
+namespace giac {
+        class context;
+}
+#endif
+
 namespace GiNaC {
 
 enum Type {
@@ -212,6 +219,10 @@ public:
         {
                 return t == PYOBJECT;
         }
+#ifdef PYNAC_HAVE_LIBGIAC
+        giac::gen* to_giacgen(giac::context*) const;
+#endif
+
 	const numeric real() const;
 	const numeric imag() const;
 	const numeric numer() const;
@@ -244,6 +255,7 @@ public:
 	const numeric doublefactorial() const;
 	const numeric binomial(const numeric &k) const;
 	const numeric bernoulli() const;
+	const numeric hypergeometric_pFq(const std::vector<numeric>& a, const std::vector<numeric>& b, PyObject* parent) const;
 	const numeric fibonacci() const;
 	const numeric isqrt() const;
 	const numeric sqrt() const;
@@ -317,6 +329,7 @@ const numeric factorial(const numeric &n);
 const numeric doublefactorial(const numeric &n);
 const numeric binomial(const numeric &n, const numeric &k);
 const numeric bernoulli(const numeric &n);
+const numeric hypergeometric_pFq(const std::vector<numeric>& a, const std::vector<numeric>& b, const numeric &z, PyObject* parent);
 const numeric fibonacci(const numeric &n);
 const numeric isqrt(const numeric &x);
 const numeric sqrt(const numeric &x);
